pub struct MockAccountsApi {
AccountsApi_expectations: MockAccountsApi_AccountsApi,
}Fields
AccountsApi_expectations: MockAccountsApi_AccountsApiImplementations
Sourceimpl MockAccountsApi
impl MockAccountsApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockAccountsApi
impl MockAccountsApi
Sourcepub fn expect_get_web_authn_login_assertion_options(
&mut self,
) -> &mut Expectation
pub fn expect_get_web_authn_login_assertion_options( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the get_web_authn_login_assertion_options method
Sourcepub fn expect_post_password_prelogin(&mut self) -> &mut Expectation
pub fn expect_post_password_prelogin(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_password_prelogin method
Sourcepub fn expect_post_register_finish(&mut self) -> &mut Expectation
pub fn expect_post_register_finish(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_register_finish method
Sourcepub fn expect_post_register_send_verification_email(
&mut self,
) -> &mut Expectation
pub fn expect_post_register_send_verification_email( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the post_register_send_verification_email method
Sourcepub fn expect_post_register_verification_email_clicked(
&mut self,
) -> &mut Expectation
pub fn expect_post_register_verification_email_clicked( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the post_register_verification_email_clicked method
Sourcepub fn expect_post_trial_initiation_send_verification_email(
&mut self,
) -> &mut Expectation
pub fn expect_post_trial_initiation_send_verification_email( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the post_trial_initiation_send_verification_email method